@@ -1,4 +1,5 @@
 """mindcv init"""
+from . import data, loss, models, optim, scheduler, utils
 from .data import *
 from .loss import *
 from .models import *
@@ -7,8 +8,6 @@ from .scheduler import *
 from .utils import *
 from .version import __version__
 
-from . import data, loss, models, optim, scheduler
-
 __all__ = []
 __all__.extend(data.__all__)
 __all__.extend(loss.__all__)
