@@ -1,6 +1,7 @@
-''' loss init '''
-from .cross_entropy_smooth import CrossEntropySmooth
+""" loss init """
+from . import binary_cross_entropy_smooth, cross_entropy_smooth, loss_factory
 from .binary_cross_entropy_smooth import BinaryCrossEntropySmooth
+from .cross_entropy_smooth import CrossEntropySmooth
 from .loss_factory import create_loss
 
 __all__ = []
