@@ -1,6 +1,6 @@
-''' optim init '''
-from .optim_factory import create_optimizer
+""" optim init """
 from . import optim_factory
+from .optim_factory import create_optimizer
 
 __all__ = []
 __all__.extend(optim_factory.__all__)
